Big Game: Washington, D.C. (Qualifier) Dream Wizards, Rockville, Maryland June 11th 2005 3R+F 43 players Matt Morgan Deck Name: Now For the Main Event - Zombies!!! Description: Overwhelm the table with your need for tasty brains. Pretty obvious choices here. Le Dinh Tho was a last-minute substitution for a 3rd Isabel. I'm pretty sure I wouldn't have won without him. Yet again I make my deck too big. This should've been in the 70-80 card range. I never came close to running out of cards and there were certainly some key cards I wanted to draw. Pretty standard "don't block me" package. Could've been more cards, but since the action starts at 1 stealth (2 with Andrea), this was sufficient. I used the Spectral Divinations for intercept more than once. These events worked out very well. I was lucky in drawing them early every round. Dragonbound helped me gain almost every VP all day. Six cards in hand is plenty for a Horde deck since I don't rely on any combat combos. Unmasking was discarded in round 3, but was critical in round 2 and the final. FBI Special Affairs Division is just huge. It makes a Horde with 1 life very useful indeed. I actually didn't rack up very many counters on it. It mostly served as a deterrant. I had meant to replace 3 Deflections with Redirections to save blood, but I forgot. Don't know if that would've made a difference. The bounce was crucial in round 2 and the final but useless in rounds 1 and 3. Only played Poison Pill once and it didn't change the outcome of the referendum. I keep trying with this card, but I've yet to have any positive outcome. The only nice thing is the Hordes can play it. Crypt (12 cards, min=13, max=28, avg=5.25) ------------------------------------------ 3x Andrea Giovanni 7 DOM NEC pot vic Giovanni:2 2x Isabel Giovanni 5 DOM NEC pot Giovanni:2 2x Rudolfo Giovanni 3 NEC Giovanni:2 1x Carlotta Giovanni 7 NEC POT dom obf Giovanni:2 1x Gillespi Giovanni 7 DOM NEC POT aus Giovanni:2 1x Le Dinh Tho 5 NEC aus dom Nagaraja:2 1x Gloria Giovanni 4 DOM nec Giovanni:2 1x Lia Milliner 3 dom nec Giovanni:3 Library (90 cards) Master (17) 2x Acquired Ventrue Assets -- Great card for this deck. 1x Barrens, The -- Got it early in almost every round. 2x Blood Doll -- I'm something of a Blood Doll addict, so it was kind of scary playing with only two of them. Worked out well, though. 1x Charisma 1x Creepshow Casino -- Never really needed it, but I didn't face heavy intercept. 1x Dreams of the Sphinx -- Gave me a turn 2 Andrea twice. 2x Fame -- Can't live without it. 1x Giant's Blood -- Played it right before Oscar was going to play his in the finals. 1x Jake Washington -- Great with Unmasking + FBI or just eat him for the blood. 1x KRCG News Radio -- Never needed it. 1x Morgue Hunting Ground 1x Path of Bone, The -- This was nice, but not crucial. 1x Perfectionist 1x Specialization -- I was surprised, but I hardly got any use out of this at all. I figured in a deck with 18 of the same card, this would be a killer. It ended up being practically useless. Action (8) 1x Far Mastery -- Stole a Procurer in the 3rd round. 7x Govern the Unaligned -- Used both ways. This ended up being a good number. Ally (20) 2x Leonardo, Mortician -- He's better than Procurer. Don't even try to tell me otherwise! 18x Shambling Hordes -- Good number! Action Modifier (12) 5x Call of the Hungry Dead 7x Seduction Action Modifier/Reaction (4) 4x Spectral Divination Reaction (16) 7x Deflection 2x Poison Pill 7x Wake with Evening's Freshness Combat (10) 6x Fake Out -- I hardly needed these. I was fortunate not to run into any gun decks. 4x Spiritual Intervention Event (3) 1x Dragonbound 1x FBI Special Affairs Division 1x Unmasking, The